def color_list():
    color_list = [
        'black', 'white', 'red', 'green', 'blue', 'yellow', 'orange', 'purple',
        'pink', 'brown', 'gray', 'cyan', 'magenta', 'lightblue', 'lime', 'maroon',
        'navy', 'olive', 'teal', 'violet', 'silver', 'gold', 'skyblue', 'coral',
        'indigo', 'lavender', 'orchid', 'salmon', 'tan', 'aquamarine'
    ]
    return color_list


def name_list():
    human_names = [
        'Liam', 'Olivia', 'Noah', 'Emma', 'Oliver', 'Ava', 'Ethan', 'Sophia', 'Aiden', 'Isabella',
        'Muhammad', 'Mia', 'James', 'Charlotte', 'Benjamin', 'Amelia', 'Lucas', 'Harper', 'Mason', 'Evelyn',
        'Elijah', 'Luna', 'Alexander', 'Ella', 'William', 'Grace', 'Henry', 'Victoria', 'Michael', 'Scarlett',
        'Daniel', 'Chloe', 'Logan', 'Zoe', 'Matthew', 'Riley', 'Jackson', 'Lily', 'Sebastian', 'Layla',
        'David', 'Nora', 'Joseph', 'Sofia', 'Samuel', 'Eleanor', 'Gabriel', 'Avery', 'Carter', 'Penelope',
        'Owen', 'Ellie', 'John', 'Aubrey', 'Dylan', 'Madison', 'Luke', 'Lillian', 'Anthony', 'Addison',
        'Isaac', 'Aria', 'Andrew', 'Elizabeth', 'Lincoln', 'Hannah', 'Christopher', 'Layla', 'Joshua', 'Grace',
        'Wyatt', 'Mila', 'Nathan', 'Lily', 'Ryan', 'Hazel', 'Eli', 'Ellie', 'Hunter', 'Natalie',
        'Levi', 'Zoey', 'Christian', 'Liliana', 'Jaxon', 'Aurora', 'Julian', 'Nevaeh', 'Landon', 'Leah',
        'Aaron', 'Savannah', 'Caleb', 'Audrey', 'Isaiah', 'Brooklyn', 'Thomas', 'Bella', 'Connor', 'Claire'
    ]
    return human_names


def fact_list():
    fact_list = [
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "Hippopotamus milk is pink.",
        "The unicorn is the national animal of Scotland.",
        "A group of ferrets is called a 'business'.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "An octopus has three hearts.",
        "The word 'bookkeeper' and 'bookkeeping' are the only unhyphenated English words with three consecutive double letters.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "Cleopatra lived closer in time to the Moon landing than to the construction of the Great Pyramid of Giza.",
        "A crocodile cannot stick its tongue out.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The Hawaiian alphabet only has 12 letters.",
        "Koalas have unique fingerprints, similar to humans.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "Bananas are berries, but strawberries are not.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "A giraffe's neck contains the same number of vertebrae as a human's.",
        "An ostrich's eye is bigger than its brain.",
        "The world's oldest known recipe is for beer.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The first recorded game of baseball was played in 1846 in Hoboken, New Jersey.",
        "The heart of a shrimp is located in its head.",
        "The name for the shape of Pringles is called a 'hyperbolic paraboloid.'",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters.",
        "The unicorn is the national animal of Scotland.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The world's oldest known recipe is for beer.",
        "A group of ferrets is called a 'business'.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters.",
        "The unicorn is the national animal of Scotland.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The world's oldest known recipe is for beer.",
        "A group of ferrets is called a 'business'.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters.",
        "The unicorn is the national animal of Scotland.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The world's oldest known recipe is for beer.",
        "A group of ferrets is called a 'business'.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters.",
        "The unicorn is the national animal of Scotland.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The world's oldest known recipe is for beer.",
        "A group of ferrets is called a 'business'.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters.",
        "The unicorn is the national animal of Scotland.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The world's oldest known recipe is for beer.",
        "A group of ferrets is called a 'business'.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters.",
        "The unicorn is the national animal of Scotland.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The only letter that doesn't appear on the periodic table is the letter 'J'.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The world's oldest known recipe is for beer.",
        "A group of ferrets is called a 'business'.",
        "A 'jiffy' is an actual unit of time: 1/100th of a second.",
        "A day on Mars is just slightly longer than a day on Earth, lasting 24 hours, 39 minutes, and 35.244 seconds.",
        "A group of owls is called a 'parliament'.",
        "The name 'Nintendo' is a combination of the Japanese words 'Nin-ten-do,' which mean 'leave luck to heaven.'",
        "The average human dream lasts only 2 to 3 seconds.",
        "Vending machines kill more people each year than sharks do.",
        "The only letter that doesn't appear in the name of a U.S. state is the letter 'Q'.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "Babies have around 100 more bones than adults, which fuse together as they grow.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "Cows have best friends and can become stressed when they are separated from them.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "A snail can sleep for three years.",
        "The oldest known customer complaint dates back to ancient Babylon, around 1750 BC.",
        "The average human dream only lasts 2 to 3 seconds.",
        "Slugs have four noses.",
        "In a room of just 23 people, there's a better-than-even chance that two of them share the same birthday.",
        "An adult human is made up of around 7,000,000,000,000,000,000,000,000,000 atoms.",
        "The shortest war in history was between Britain and Zanzibar on August 27, 1896. Zanzibar surrendered after 38 minutes.",
        "Bananas are berries, but strawberries are not.",
        "Octopuses have three hearts: two pump blood to the gills, and one pumps it to the rest of the body.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The average person spends 6 months of their life waiting for red lights to turn green.",
        "The strongest muscle in the human body is the masseter (jaw muscle).",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "The average person walks the equivalent of five times around the world in their lifetime.",
        "The color red doesn't make bulls angry; they are color-blind to red.",
        "The Hawaiian alphabet only has 12 letters.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "Honey never spoils. Archaeologists have found pots of honey in ancient Egyptian tombs that are over 3,000 years old.",
        "The Great Wall of China is not visible from space with the naked eye.",
        "Bananas are berries, but strawberries are not.",
        "The Eiffel Tower can grow up to 6 inches (15 centimeters) during the summer due to the expansion of the iron on hot days.",
        "The world's smallest mammal, the bumblebee bat, weighs less than a penny.",
        "Cows have best friends and can become stressed when they are separated.",
        "Polar bears have black skin under their white fur to better absorb and retain heat.",
        "A group of flamingos is called a 'flamboyance'.",
        "There are more possible iterations of a game of chess than there are atoms in the known universe.",
        "A day on Venus is longer than its year. Venus takes about 243 Earth days to rotate on its axis, while it only takes about 225 Earth days to orbit the Sun.",
        "A jiffy is an actual unit of time: 1/100th of a second.",
        "The unicorn is the national animal of Scotland.",
        "The average person will spend six months of their life waiting for red lights to turn green.",
        "A newborn baby has around 100 more bones than a fully grown adult.",
        "The Great Pyramids of Giza were built around 4,500 years ago and are the oldest of the Seven Wonders of the Ancient World.",
        "A group of penguins in the water is called a 'raft', while a group of penguins on land is called a 'colony'.",
        "The longest hiccuping spree lasted for 68 years.",
        "A panda's diet consists almost entirely of bamboo.",
        "The tongue is the strongest muscle in the human body in proportion to its size.",
        "The Hawaiian alphabet only has 12 letters."]
    return fact_list



import openpyxl as xl


def new_sheet(wb, title):
    wb.create_sheet(title)


def cell_font(worksheet, cell, font):
    worksheet[cell].font = font


def cell_color(worksheet, cell, color):
    worksheet[cell].fill = color


def list_entry(worksheet, coulum, list):
    for items in list:
        row = worksheet.max_row + 1
        worksheet.cell(row, coulum).value = items


def cell_entry(worksheet, cell, value):
    worksheet[cell].value = value


def merge_cell(worksheet, cell1, cell2):
    worksheet.merge_cells(cell1 + ':' + cell2)


def sheet_protect(worksheet, password):
    worksheet.protection.sheet = True
    worksheet.protection.password = password


def sheet_unprotect(worksheet):
    worksheet.protection.sheet = False



from FedxD import color
from FedxD import converters
from FedxD import random
from FedxD import excel
from FedxD import discord
from FedxD import pygame

print("('FedxD')Package Initialized Successfully")


import random
import pygame as pg
import pygame.event


def check_collision(rect1, rect2):
    return rect1.colliderect(rect2)

def handle_event(events):
    for event in events:
        if event.type == pg.QUIT:
            pg.quit()
            quit()
        if event.type == pg.KEYDOWN:
            if event.key == pg.K_ESCAPE:
                pg.quit()
                quit()
def render_text(screen,text, font, color, x, y):
    text_surface = font.render(text, True, color)
    screen.blit(text_surface, (x, y))
def random_spawn_x(WIDTH,obj_width):
    return random.randrange(0 + obj_width + 5 , WIDTH - obj_width - 5)
def random_spawn_y(HEIGHT,obj_HEIGHT):
    return random.randrange(0 + obj_HEIGHT + 5 , HEIGHT - obj_HEIGHT - 5)






import discord
import discord.ext

def swear_detection(message, swear_words):
    for word in swear_words:
        if word in message.content.lower():
            return True
        else:
            return False




class Time:
    @staticmethod
    def DaytoSec(days):
        sec = days * 24 * 60 * 60
        return sec
    @staticmethod
    def SectoDay(sec):
        days = sec / 24 / 60 / 60
        return days


class Bytes:
    @staticmethod
    def MBtoB(MB):
        B=MB*1024*1024
        return B
    @staticmethod
    def GBtoB(GB):
        B = GB*1024*1024*1024
        return B
    @staticmethod
    def TBtoB(TB):
        B = TB*1024*1024*1024*1024
        return B
    @staticmethod
    def KBtoB(KB):
        B = KB*1024
        return B
    @staticmethod
    def BtoKB(B):
        KB = B/1024
        return KB
    @staticmethod
    def BtoMB(B):
        MB = B/1024/1024
        return MB
    @staticmethod
    def BtoGB(B):
        GB = B/1024/1024/1024
        return GB
    @staticmethod
    def BtoTB(B):
        TB = B/1024/1024/1024/1024
        return TB
class Weight:
    @staticmethod
    def KGtoP(KG):
        P = KG*2.2
        return P
    @staticmethod
    def PtoKG(P):
        KG = P/2.2
        return
class Temperature:
    @staticmethod
    def CtoF(C):
        F = (C*9/5)+32
        return F
    @staticmethod
    def FtoC(F):
        C = (F-32)*5/9
        return C
    @staticmethod
    def CtoK(C):
        K = C+273.15
        return K
    @staticmethod
    def KtoC(K):
        C = K-273.15
        return C
    @staticmethod
    def FtoK(F):
        C=(F-32)*5/9
        K=C+273.15
        return K
    @staticmethod
    def KtoF(K):
        C = K-273.15
        F = (C*9/5)+32
        return F
class Length:
    @staticmethod
    def MtoF(M):
        F = M*3.28084
        return F
    @staticmethod
    def FtoM(F):
        M = F/3.28084
        return M
    @staticmethod
    def CmtoI(Cm):
        I = Cm/2.54
        return I
    @staticmethod
    def ItoCm(I):
        Cm = I*2.54
        return Cm
    @staticmethod
    def FtoY(F):
        Y = F*3
        return Y
    @staticmethod
    def YtoF(Y):
        F = Y/3
        return F
    @staticmethod
    def MtoY(M):
        Y = M*1.09361
        return Y
    @staticmethod
    def YtoM(Y):
        M = Y/1.09361
        return M



import twine
from setuptools import setup , find_packages
with open("README.md", "r") as fh:
    long_description = fh.read()
setup(name='FedxD',
    version='0.7',
    packages=['FedxD'],
    author='FedxD',
    author_email='abbaskazim135@gmail.com',
    description='This Package is for Quality of life stuff that you will need in your project',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/FedxD',
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    pyton_requires='>=3.10',
    requires=['openpyxl','discord','pygame'],

)


from FedxD  import Lists
import random


def date(year):
    month = random.randint(1, 12)
    if month == 2:
        day = random.randint(1, 28)
    else:
        day = random.randint(1, 30)
        date = f"{day}/{month}/{year}"
        return date


def color():
    return random.choice(Lists.color_list())


def name():
    return random.choice(Lists.name_list())


def age():
    return random.randint(1, 80)


def fact():
    return random.choice(Lists.fact_list())


def true_false():
    return random.choice([True, False])
